### Name: divcmax
### Title: Maximal value of Rao's diversity coefficient also called
###   quadratic entropy
### Aliases: divcmax
### Keywords: multivariate

### ** Examples

par.safe <- par()$mar
data(elec88)
par(mar = c(0.1, 0.1, 0.1, 0.1))
# Departments of France.
area.plot(elec88$area)

# Dissimilarity matrix.
d0 <- dist(elec88$xy)

# Frequency distribution maximizing spatial diversity in France
# according to Rao's quadratic entropy.
France.m <- divcmax(d0)
w0 <- France.m$vectors$num
v0 <- France.m$value
(1:94) [w0 > 0]

# Smallest circle including all the 94 departments.
# The squared radius of that circle is the maximal value of the
# spatial diversity.
w1 = elec88$xy[c(6, 28, 66), ]
w.c = apply(w1 * w0[c(6, 28, 66)], 2, sum)
symbols(w.c[1], w.c[2], circles = sqrt(v0), inc = FALSE, add = TRUE)
s.value(elec88$xy, w0, add.plot = TRUE)
par(mar = par.safe)

## Not run: 
##D # Maximisation of Rao's diversity coefficient
##D # with ultrametric dissimilarities.
##D data(microsatt)
##D mic.genet <- count2genet(microsatt$tab)
##D mic.dist <- dist.genet(mic.genet, 1)
##D mic.phylog <- hclust2phylog(hclust(mic.dist))
##D plot.phylog(mic.phylog)
##D mic.maxpond <- divcmax(mic.phylog$Wdist)$vectors$num
##D dotchart.phylog(mic.phylog, mic.maxpond)
## End(Not run)



